function [id, state] = idetge (iA)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Get the interval enclosure of det(iA) using the Gaussian elimination.
%
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ... an interval matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   id ... interval enclosure of determinant
%   state ... state 'sin' - singularity occurred during GE, 
%               'vec' - finite enc returned
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2011  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2019-03-03    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%
%ENDDOC===================================================================
 
  [iA, iB, state, d] = ige(iA, [], 0);
  
  if strcmp(state, 'sin')
    id = infsupdec(-Inf, Inf);
  else
    state = 'vec';
    id = d * prod(diag(iA));
  end
endfunction