function id = idethull(iA, edgedet)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes hull of interval determinant of matrix by brute force
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  square interval or real matrix 
%   edgedet ... displays edgematrices with certain determinants
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   id ...  determinant
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   Brute force according to Edge theorem by Rohn is used, therefore it may 
%   take a lot of time  
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2017-06-26    first version
%
%------------------------------------------------------------------------
% .Todo.
%  Verified real det computation 
%  Problem for matrix [1,2] -1
%                       -1   [1,3] gives wrong results !!!!!!!  
%   trouble seems to be in vdet :(
%  todo 2x2 case
%  better mapping of -1/1 vector to M
%
%ENDDOC===================================================================


[m, n] = size(iA);
if m != n
  error "idethull: Matrix must be n x n";
end

if (n==2)
  id = iA(1,1)*iA(2,2) - iA(2,1)*iA(1,2);  
else 
  % counting number of nonzero elements + creating bitmap of nonzero elements
  % also those elements that have nonzero width
  bitmap = ((inf(iA) < 0) | (sup(iA)>0)) & (wid(iA) > 0);
  c = sum(sum(bitmap));
  
  yn = generateyn(c);
  
  detmin = Inf;
  detmax = -Inf;
  
  Ac = mid(iA);
  Arad = rad(iA);
  
  % checking all edge matrices 
  for i=1:(2^c)
    gen = yn(i, :);
    
    % mapping gen into M
    M = zeros(n,n);
    
    dummyc = 1;
    for i=1:n
      for j=1:n
        if (bitmap(i,j) == 1)
          M(i, j) = gen(dummyc);
          dummyc = dummyc + 1;
        end   
      end
    end
    
    edgeM = Ac + M.* Arad;
    d = vdet(edgeM);   % verified det
    
    
    % disp edge matrices with certain determinant
    if nargin == 2
      if (d == edgedet)
        disp('------------');
        disp(edgeM);
        disp('------------');       
      end
    end
    
    if(d > detmax)
      detmax = d;
    end
    
    if(d < detmin)
      detmin = d;
    end
    
  end
  
    id = infsup(detmin, detmax);
  
  end
end




























