function [iA, ihull] = idetexmpl(exmplname)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%  Set of examples of interval determinant matrices with its interval hull
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   exmplname ... name of an example
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iA ... interval matrix
%   ihull ... hull of the interval determinant
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   In comments of each example we can found the source
%   verified determinants are computed using idethull
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 2.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 2.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 2.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-01-09    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%   Other examples. 
%
%ENDDOC===================================================================  
  
  
pkg load interval;

switch (exmplname)
  
%---------------------------------------------------------------------------  
% Example in 2d
case 'exmpl2d'
  iA = infsup([4 -1; -1 -6], [6 1; 1 -4])
  ihull = infsup(-37, -15);    
  
%---------------------------------------------------------------------------  
% Example from Horacek J., Hladik M., Matejka J., Determinants of interval matrices
case 'horacek1'
  iA = midrad([1 2 3 ; 4 5 6; 7 8 9], 1);
  ihull = infsup(-98, 100);   
  
%---------------------------------------------------------------------------  
% T. Nirmala, THE DETERMINANT OF AN INTERVAL MATRIX
% USING GAUSSIAN ELIMINATION METHOD, IJPAM, 2013 - example 6
case 'nirmala6'
  iA = infsup([3.7 -1.5 0; -1.5 3.7 -1.5; 0 -1.5 3.7], [4.3 -0.5 0; -0.5 4.3 -0.5; 0 -0.5 4.3]);  
  ihull = infsup(34.0029999999999, 75.207);
  
%---------------------------------------------------------------------------  
% T. Nirmala, THE DETERMINANT OF AN INTERVAL MATRIX
% USING GAUSSIAN ELIMINATION METHOD, IJPAM, 2013 - example 7  
case 'nirmala7'  
  iA = infsup([4 -1 -1 -1; -1 -6 -1 -1; -1 -1 9 -1; -1 -1 -1 -11], [6 1 1 1; 1 -4 1 1; 1 1 11 1; 1 1 1 -9]);
  ihull = infsup(1000, 4786);

%---------------------------------------------------------------------------   
case 'hadamard4'
  iA = midrad([1 1 1 1 ; 1 -1 1 -1; 1 1 -1 -1; 1 -1 -1 1] , 0.1);
  ihull = infsup(10.4975999999999, 23.4256);
  otherwise
    disp('Error: example with that name does not exist') 
  
endswitch
  
  
end