function lambdasupper = eigsymencdirect(iA)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Computes verified upper bounds on eigenvalue of iA
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ... n x n real matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   lambdasupper ... verified uper bounds on lambdas of iA
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%  Uses direct interlacing algorithm by Milan Hladik from
%  Bounds on real eigenvalues and singular values of interval matrices.
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2017  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-01-14    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%
%ENDDOC===================================================================


[m, n] = size(iA);

if (m != n)
  error('eigsymencdirect works only for n x n matrices !!!');
end

lambdasupper = repmat(Inf, n, 1);
iB = iA;
upperb = l1upperb(iB);


for k=1:n 

   lambdasupper(k) = upperb;
   % choosing an index of row and column to omit

    [index, upperb] = selectindex(iB);
    indices = [1:(index-1), (index+1):(n-k+1)];
    % omitting index-th row and column
    iB = iB(indices, indices); 


end


end



% function selects the minimum index it also returns the bound on l1 
function [index, upperb] = selectindex(iB)

  [m, n] = size(iB);
  
  index = 1;
  minimum = Inf;
  
  if (n == 1)
    index = 1;
    minimum = iB(1, 1);
  else
  
    for i=1:n
        indices = [1:(i-1), (i+1):n];
        iC = iB(indices, indices);
        upperb = l1upperb(iC);
        if (upperb < minimum)
           minimum = upperb;
           index = i;     
        end
    
    end
  
    upperb = minimum;
    
  end
end