function [ iV, eigenc ] = imateigv( iA, option )
%BEGINDOC=================================================================
% .Author.
%
%  David Riha, Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Computes eigenvectors of n x n interval matrix iA if option = 'normal'. Computes 
%   eigenvectors of symetric interval iA if input option='sym' is used.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA      ...  n x n interval matrix
%   option  ...  'normal' for standart computation
%                  'sym' for eigenvectors of only symmetric subset of iA
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iV ... n x 1 vector of eigenvectors of (symmetric) iA
%   eigenc ... returns eigenvalue enclosures for possible  further use
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   
%------------------------------------------------------------------------
%  .Licence.
%  
%       
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-8-25      first version 
%
%------------------------------------------------------------------------
% .Todo.
%
%  - fix isnan trouble 
%
%ENDDOC===================================================================


[n,m] = size(iA);
if n ~= m
    warning('Input needs to be square matrix!');
    return
end

if n==1
    warning('Input matrix has to have dimensions at least 2x2!');
    return
end


%choosing method for finding eigenvalues
if exist('option','var')
    if strcmp(option, 'sym')
        eigvalues = eigsymenc(iA);
    elseif strcmp(option, 'normal')
        eigenc = ieigbauerfike(iA);
    else
        warning('Wrong option');
        iV = [];
        return
    end
else 
    eigenc = ieigbauerfike(iA);
end

iV = [];

for i = 1:n

    iB = iA - diag( repmat(eigenc(i), n, 1) );
    eigvfound = false; % eigenvector found
    
    for j = 1:n
        for k = 1:n
            
        % submatrix of iB    
        iBsub = iB;
        %iA-eig(i) is singular, it's potentially regular without one row and column 
        % exluding j-th row
        iBsub = iB([1:(j-1), (j+1):n], :); 
        ib = iBsub(:,k); 
        iBsub = iBsub(:, [1:(k-1), (k+1):n]);
          
        % solving system for possible eigenvector           
        x = iBsub \  (-ib);
        
        %adding fixed result (for column Xvector) back to result x
        %if k == n
        %    x = [x; 1];
        %else
        %k    
        x = [x([1:(k-1)]); 1; x([(k):(n-1)])];
        %end
        
        % line should be if not(any(isnan(x))) || isempty(x)
        % in Matlab !!!
        if none(isempty(x))
            iV = [iV, x];
            %break because we found good vector
            eigvfound = true;
            break;
        end
      end
      if eigvfound
        break
      end  
      
    end
    if ~eigvfound
         warning('Function failed to find eigenvectors.');
            iV = [];
            return
    end
end

