function [ix, state, ver] = ilsenc(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes enclosure of square iA x = ib
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   ib ... interval right hand side
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ix ... enclosure of the ILS solution set 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2019-03-22    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%
%ENDDOC===================================================================


ver = 1;
state = 'vec';

[m, n] = size(iA);

if (m ~=n)
  error('ilsenc: works only of square systems');  
end


% iA is diagonal
if (isdiagonal(iA))
   [ix, state] = ibacksubst(iA, ib);   
   return;
end 

[ix, state] = ilshbrenc(iA, ib);


end


