function [ix, state] = ilsgeenc(iA,ib, pre=1)

%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   function provides enclosure of a solution set of the interval system Ax=b
%   using interval Gaussian elimination
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ... matrix to be eliminated  
%   ib ... possible right hand side of system Ax=b, supports multiple
%   righthand sides [OPTIONAL]
%
%   Possible calls: 
%   C = gausselim(A)
%   [C, d, state] = gausselim(A, b)
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ix ... enclosure of solution of Ax=b
%   state ... is a string flag containing the type of solution
%    'inf' - infinite
%    'non' - no solution
%    'vec' - interval vector
%    'sin' - we ended during gauss elimination
%    'fop' - failure of preconditioning - use different method
%   pre ... says if we precondition the system
%       1 - we precondition (default)
%       0 - no preconditioning
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   NOTE - 'sin' can also mean, that all possible pivots contain 0 because 
%   of interval widening caused by interval operations
%   'inf' can also mean, that intersection of all equations containing
%   x_n during backward substitution is unbouded because of interval widening
%   caused by interval operations
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2011  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2011-05-20      first version
%   2011-07-12      works for point real matrix
%   2011-07-29      preconditioning failure detection
%
%------------------------------------------------------------------------
% .Todo.
%   
%   Rewrite better partial pivoting
%   
%
%ENDDOC===================================================================

[m, n] = size(iA);

if( n > m )
    error( 'ilsgaussenc: wrong matrix size - m must be >= n' );
end 

%[A, b] = tointval(A, b);

% preconditioning if wanted

[iC, id, state] = ige(iA, ib, pre);

if (strcmp(state, 'ref'))
  [ix, state] = ibacksubst(iC, id);
end

end