function [ihull, state, ver] = ilshullver(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   uses verified LP, computes hull of iA x = ib 
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   ib ... interval right hand side
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ix ... hull of the ILS solution set 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-07-15    first version
%   2018-10-17    mistake with wrong ul, ub corrected
%
%------------------------------------------------------------------------
% .Todo.
%
%  - rework initial enclosure
%  - add verification to linear programming
%
%ENDDOC===================================================================


ver = 0;
state = 'vec';

[m, n] = size(iA);
%[A, b] = tointval(iA, b);


% iA is diagonal
if (isdiagonal(iA))
   [ihull, state] = ibacksubst(iA, ib);   
   return;
end 




    
maxx = repmat(-Inf, n, 1);
minx = repmat(Inf, n, 1);

Ac = mid(iA);
Delta = rad(iA);
bc = mid(ib);
delta = rad(ib);

if (m==n)
  ix = ilshbrenc(iA, ib);
end

if (m > n)
  ix = oilsrohnenc(iA, ib);
end

sign = intsign(ix);

sign = sign';
    
% add exception    
    
    
% set of all orthants to search: orthx 
zerospos = find( sign == 0 );
zeronum = length(zerospos);
Yn = generateyn(zeronum);

% sign vector of all orthants that need to be checked
len = 2^zeronum;
orthx = repmat( sign, len, 1 );
orthx(:, zerospos) = Yn;


I = eye(n);

for i=1:len
    y = orthx(i, :);    
    
    Dy = diag(y);
   
    DeltaDy = Delta * Dy;
    C = [ -Ac - DeltaDy ; Ac - DeltaDy; (-y)];
    d = [ -bc + delta; bc + delta ; 0];
    I = eye(n);
    
    
      % computing for each variable max and min
    for j=1:n
        
        % j-th column of eye matrix
        ej = I(:, j);
        
        % computing minimum
        [flag,prim,dual,h] = verlinprog(C', -ej, d);
        minx = min(minx, inf(dual));
            
        % computing maximum
        [flag,prim,dual,h] = verlinprog(C', ej, d);
        maxx = max(maxx, sup(dual));
                        
    end        
    
     
end
    

ihull = infsup(minx, maxx);

end


