function [iA, ib] = ilsrandfix(m, n, fixrad, midbounds)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   creates a random ILS iA x = ib with all intervals having fix radius
%   m x n system where m > n is likely to be unsolvable
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   ib ... interval right hand side
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   m ... number of equations
%   n ... number of variables
%   fixrad ... fixed radius of all intervals
%   midbounds ... 2-array - [a,b] a <= b interval for random midpoints 
%                 if a=b  we get the same midpoints everywhere
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-03-20    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================


if (nargin < 4)
  midbounds = [-10,10];
end

if midbounds(1) > midbounds(2)
     error("ilsrandsolfix: wrong [a,b] bounds for midpoints a >= b");   
end

if(midbounds(1) == midbounds(2))
    Arand = repmat(midbounds(1), m, n);
    brand = repmat(midbounds(1), m, 1);
else 
    Arand = (midbounds(2) - midbounds(1)) * rand(m, n);
    Arand = Arand + midbounds(1);  
    brand = (midbounds(2) - midbounds(1)) * rand(m, 1);
    brand = brand + midbounds(1);  
end  


iA = midrad(Arand, fixrad);
ib = midrad(brand, fixrad);




end