function [is, ver] = issolvable(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes whether iA x = ib has any subsystem solvable
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   ib ... interval right hand side
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   is ... 1 if is solvable
%   ver ... 1 if the resukt is verified
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   computes solution x = pinv(Ac)*bc, and checks it by Oettli-Prager
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-03-24    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
% add verification
%
%ENDDOC===================================================================

[m, n] = size(iA);

is = 0;
ver = 0;

Ac = mid(iA);
bc = mid(ib);

x = pinv(Ac)*bc;

left = abs( Ac * x - bc );
right = rad(iA)*abs(x) + rad(ib);

if (all (left <= right ))
   is = 1;
   ver = 0; 
end




end