function [uns, ver] = isunseig(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   unverified!!! - checks whether iA x = ib is unsolvable
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  m x n matrix, if the line is very long then we can
%          wrap it like this 
%   ib ...  n-dimensional right-hand side vector
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   uns ... 1 if unsolvable
%   ver ... 1 if the result is verified, 0 otherwise
%
%------------------------------------------------------------------------
% .Implementation details. 
%  checks whether varrho( |A_c^+| Ad ) < 1
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-03-20      first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================


uns = 0;
ver = 0;

iA = [iA, ib];


Ac = mid(iA);
Ad = rad(iA);

R = abs(pinv(Ac));

C = R * Ad;
e = max(abs(eig(C)));

if e < 1
  uns = 1;
end



    
end