function [uns, ver] = isunssubsq(iA, ib, itnum)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes an enclosure of a system Ax=b
%   using Jacobi iterative method with preconditioning  
%   works for square and overdetermined systems
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  m x n matrix, if the line is very long then we can
%          wrap it like this 
%   ib ...  n-dimensional right-hand side vector
%   it ... number of iterations (random subsystems chosen) 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   uns ... 1 if unsolvable
%   ver ... 1 if the result is verified, 0 otherwise
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-03-20      first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================


uns = 0;
ver = 0;

if nargin == 2
  itnum = 5;
end

[iC, id] = randsubsq(iA, ib);
ix = iC \ id;

empty = 0;
i = 2;
while (!empty) && (i<=itnum)
 
  [iC, id] = randsubsq(iA, ib);
  ixnew = iC \ id;
  inter = intersect(ixnew, ix);

  if(any(isempty(inter)))
    empty = 1;
    uns = 1;
    ver = 1;
  end
 
  i = i + 1;


end
 



    
end