function [compA] = imatcomp(iA)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes comparison matrix <A> to iA
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   compA ...  comparison matrix
%
%------------------------------------------------------------------------
% .Implementation details. 
%
% Definition of <A> in Ostrowski, Uber die determinanten mit uberwiegender
% hauptdiagonale, 1937 
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-09-24    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================


invA = [];

[m, n] = size(iA);

if (m != n)
  error('imatcomp: matri must be n x n');  
end

preA = -mag(iA);
compA = tril(preA, -1) + diag(diag(mig(iA))) + triu(preA, 1);

end