function iAk = imatpow( iA, k )
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Computes an enclosure k-th power.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  n x n real interval matrix
%   k  ...  natural power of matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iAk ... iA to the power of k 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   This function is using well know exponentiation by squaring method
%   https://en.wikipedia.org/wiki/Exponentiation_by_squaring
%
%------------------------------------------------------------------------
%  .Licence.
%  
%       
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-8-25   first version 
%
%------------------------------------------------------------------------
% .Todo.
%   
%  - more sophisticated call of functions 
%
%ENDDOC===================================================================

[n, m] = size(iA);
if n ~= m
    warning('imatpow: input needs to be a square matrix!');
    return
end

if (k < 1)
   error ('imatpow: k must be > 0');
end  

% nonegative matrix
if all(all(inf(iA) > 0) )
  lowerb = inf(iA)^k;
  upperb = sup(iA)^k;
  iAk = infsup(lowerb, upperb);
else



iAk = imatpowbin(iA, k);

end

end