function [ iV ] = imatpowbin( iA, k )
%BEGINDOC=================================================================
% .Author.
%
%  David Riha, Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Computes an enclosure k-th power of interval matrix iA using 
%   exponentiation by squaring method.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  n x n real interval matrix
%   k  ...  natural power of matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iV ... n x n interval matrix 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   This function is using well know exponentiation by squaring method
%   https://en.wikipedia.org/wiki/Exponentiation_by_squaring
%
%------------------------------------------------------------------------
%  .Licence.
%  
%       
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-3-15   first version
%   2018-7-12   faster algorithm implemented
%   2018-8-25   check for k > 0 
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================

[n, m] = size(iA);
if n ~= m
    warning('Input needs to be square matrix!');
    return
end

if (k < 1)
   error ('imatpowbin: k must be > 0');
end  

binary = dec2bin(k);
iV = iA;
for j = 2:length(binary) 
    if binary(j) == '1'
        iV = iV^2 * iA;
    else
        iV = iV^2;
    end
end

end

