function [norma] = imaxnorm (iA, u)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes the (scaled) maxnorm of an interval matrix
%   scaled norms work only for square matrices
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval matrix 
%   u ... positive scaling vector (horizontal or vertical)
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   norma ...  matrix norm 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-03-16    first version
%
%------------------------------------------------------------------------
% .Todo.
%   make it work for vectors?
%
%ENDDOC===================================================================

norma = 0;
[m, n] = size(iA);

if nargin == 1
    mags = mag(iA);
    sums = sum(mags);
    norma = max(sums);   

elseif nargin == 2


  if any(u <= 0)
    error('imaxnorm: u must be positive');
  end  

  [k, l] = size(u);
  if(k>1 && l>1 )
    error('imaxnorm: u must be vector');
  end
  
  % automatic transposition of vector u
  if (k==1 && l > 1)
    u = transpose(u);
    k = length(u);
  end  
  
  
  % vector case -----------------------------------------------------
    if(n==1 || m==1) 
    
        % automatic transposition of vector iA
        if (m==1 && n > 1)
          iA = transpose(iA);
          m = length(iA);
        end  
    
        if m == k 
          norma = max( mag(iA) ./ u);  
        else
          error('imaxnorm: u has wrong size');
        end  
    else 
 
  
  % matrix case -----------------------------------------------------

      if m != n
          error('imaxnorm: matrix must be square');  
      end
      
      
      if n != k
          error('imaxnorm: wrong size of u with respect to A');    
      end

      v1 = mag(iA) * u;
      v2 = abs(v1) ./ u;
      norma = max(v2);
    end 
   
 else
  error('imaxnorm: wrong number of arguments');
end



end