function [ish, u, state] = ishmatrix(iA, checkminors)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   decides whether matrix iA is an H-matrix
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   checkminors ...  by default 1, if 0 disables checking minors of <A> when checking
%             for M-matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ish ...  1 if matrix is H-matrix
%   u ... vector u>0 witnessing that iA is a H-matrix
%   state ... 'vec' found u
%             'nou' could not find u 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%  when <A> is an M-matrix iA is H-matrix based on chapter 3.7 from A. Neumaier, Interval methods for 
%   systems of equations, 1990  
%
%  checking all principal leading minors for positivity can be time consuming 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-09-24    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%ENDDOC===================================================================

ish = 0;

[m, n] = size(iA);

if (m != n)
  error('ismmatrix: matrix must be n x n ');
end  

if (nargin < 2)
    checkminors = 1;  
end


icompA = infsupdec(imatcomp(iA));
[ish, u, state] = ismmatrix(icompA);



end