function [isreg, state, ver] = isregular(iA)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   decides whether matrix iA is regular
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   isreg ...  1 if matrix is regular
%   state ... 'reg' if iA is regular, 'unk' if unknown
%   ver ... 1 if the result is verified 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2019-03-31    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%ENDDOC===================================================================

isreg = 0;
state = 'unk';
ver = 0;

[m, n] = size(iA);

if (m != n)
  error('isregular: matrix must be n x n ');
end  

% H-matrix is regular
if (ishmatrix(iA))
  ver=1;
  isreg = 1; 
  state = 'reg';
  return;  
end

[isreg, ver] = ifcr(iA, 1);
if (isreg && ver)
  state = 'reg';  
end


end