function [f, J, initx] = inlsexmpl(exmplname, n, p)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%  Set of examples of interval nonlinear systems
% Most of the examples are the one from COPRIN database rewriten
% into a different form 
% all constraints are yet in the form ... = 0
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   exmplname ... name of an example
%   n ... dimension
%   p ... parameter if necessary
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   f ... array of functions (vector can be assigned)
%   J ... function Jacobian
%   initx ... initial box
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   In comments of each example we can found the source (usually we take not the original ones)
%   but the ones with visualisations
%   other verified determinants are computed using ilshull
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 2.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 2.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 2.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-02-09    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%   Other examples. 
%
%ENDDOC===================================================================  
  
  
pkg load interval;
pkg load symbolic;

switch (exmplname)
  
%---------------------------------------------------------------------------  
% A. Neumaier, Interval methods for systems of equations, 1990 - p. 93
case 'bronstein'
  syms x y z;
  f = @(x, y, z)([x^2 + y^2 + z^2 - 36; x + y - z; x*y + z^2 - 1]);   
  J = jacobian(f, [x, y, z]);
  initx = infsup([-10^8;-10^8; -10^8], [10^8;10^8;10^8]);
  
  
 
 
  otherwise
    disp('Error: example with that name does not exist') 
  
endswitch
  
  
end