function [y, state] = oilsrohnddir(G, g, e)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   finds positive vector d satisfying Rohn's theorem
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   G ...  matrix G from Rohn's theorem 
%   g ...  vector g from Rohn's theorem 
%   e ... small positive number (default min(min(diam(A)))/100 + 10^(-10))
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   y ... returned d
%   state ... 'vec' or 'nof' not found
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   finds Rohn d directly by solving (I-G)d = g + e
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2014  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2011-05-01    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================


% works only when spectral radius of G
% is < 1
%rho = eigs(G, 1);
%if ( rho >= 1)
%   error('Error: spectral radius of G is >= 1');
%   return;    
%end

[m,n] = size(G);
state = 'vec';

d = linsolve( (eye(n) - G) , (g + e) );
id = infsup(d);

if( any(id <= 0) )
    y = repmat(NaN, n, 1);
    state = 'nof';
    return;
end

y = d;

end