function [iA, ib, ihull] = oilsexmpl(exmplname, n, p)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%  Set of examples of interval determinant matrices with its interval hull
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   exmplname ... name of an example
%   n ... dimension
%   p ... parameter if necessary
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iA ... interval matrix
%   ib ... right-hand side vector
%   ihull ... hull of the interval determinant
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   In comments of each example we can found the source (usually we take not the original ones)
%   but the ones with visualisations
%   other verified determinants are computed using ilshull
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 2.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 2.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 2.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-10-22    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%   Other examples. 
%
%ENDDOC===================================================================  
  
  
pkg load interval;

switch (exmplname)
  
%---------------------------------------------------------------------------  
% Horacek
case 'horacek1'
iA = infsup([-0.8 -20.1; -15.6 14.8; 18.8 8.1], [0.2 -19.5; -15.2 16.7; 20.1 9.5]);
ib = infsup([292.1; -361.9; 28.4], [292.7; -361.1; 30.3]) 
ihull = [];
  
%---------------------------------------------------------------------------  
% Horacek - 
% unsolvable
case 'horacek2'
Ac = [ -6   2  -9;
   0   8   6;
   7 -9  -5;
   4  -5  -8;
  -5  -7   6]
  
bc =  [    9;
    54;
  -120;
  -95;
    57 ]
iA = midrad(Ac, 0.1);
ib = midrad(bc, 0.1);  
  
  
%---------------------------------------------------------------------------  
% Popova, Improved Solution Enclosures for Over- and
% Underdetermined Interval Linear Systems, 2006  
% unsolvable
case 'popova1' 
ia = infsup(0.999, 1.001);
iA = repmat(ia, 6, 4) + [0 1 2 0; 0 2 3 1; 1 2 3 2; 2 3 4 3; 3 4 5 5; 5 5 6 7 ];    
ib = infsup([3;1;-2; -3; 0; 0]);  
  
%---------------------------------------------------------------------------  
% Bentbib, Solving the full rank interval least squares problem, 2002
case 'bentbib1'
iA = infsup([0.1 0.9; 8.9 0.4; 0.9 6.9], [0.3 1.1; 9.1 0.6; 1.1 7.1 ]);
ib = infsup([0.8; 0.3; 6.8], [ 1.2; 0.7; 7.2]) 
ihull = [];
  
 
  otherwise
    disp('Error: example with that name does not exist') 
  
endswitch
  
  
end