function [bsqs] = bsqpilsbabonxAll(sol, nameofpils, typeofprune, limitboundboxes, numberofcycle)
%BEGINDOC=================================================================
% .Author.
%
%  Adam Szabo
%
%-------------------------------------------------------------------------
% .Description. 
%
%  The outer boundary of the boxes obtained from the B&B process,
%  by recursive division into quadrants.
%
%-------------------------------------------------------------------------
% .Input parameters.
%
%   sol ... box contains boxes obtained from the B&B process
%   nameofpils ... name of the parametric interval linear system of the example,
%   from the tests.m function
%   typeofprune ... the name of method of prunes for boxes
%   limitboundboxes ... limit on the boxes to be bounded again
%   numberofcycle ... number of iterations
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   bsqs ... output quadrants of input quadrants which contains boxes 
%   obtained from the B&B process
%  
%------------------------------------------------------------------------
% .Implementation details. 
%  
%  numberOfCycle: It may not be necessary. 
%                 It will mostly stop at the limitBoundBoxes. 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-19    first version
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================

  bs = boundsolquad(sol);
  
  [m,n] = size(bs);
  bsqs2 = [];
  bsqs = [];

  
  for j = 1:(numberofcycle)

    for i=1:(n)
     bsqso = bsqpilsbabonx(bs(:,i),nameofpils, typeofprune, limitboundboxes);
     bsqs2 = [bsqs2,bsqso];
    end
     bsqs =[bsqs, bsqs2];
  end

end
