function [newbox, flag] = ilspruneoettli(box, ipk, Ak, bk, A, b)
%BEGINDOC=================================================================
% .Author.
%
%   Jaroslav Horáček
%
%-------------------------------------------------------------------------
% .Description.
%
%   Pruning condition by necessary condition for solution of param. system
%   by doc.Mgr.Milan Hladik,PhD.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   box ... column interval vector / matrix of interval column
%   vectors initial boxe(s) 
%   ipk ... column vector of intervals - bounds for parameters
%   Ak ... cellular array of arrays A{1}=[], A{2}=[]
%   bk ... cellular array of column vectors b{1}=, b{2}=
%   A ... real matrix  
%   b ... real column vector 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newbox ... the new box after pruning the box from input
%   flag ... 0 - verified no solution in a box
%            1 - verified at least one solution
%            2 - verified whole box contain solutions
%            3 - unknown  
%
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-01-14    first version
%   2018-07-11    formula corrected - mag substituted with abs !
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================
  
    flag = 3;
    [m, n] = size(A);  
    
    %leftside = zeros(m, 1);
    %rightside = zeros(m, 1);
    
    paramnum = length(ipk); 

    leftside = A*box - b;
   % rightside = abs(A*box - b);
   rightside = zeros(m,1);
    
    for i=1:paramnum    
       
       leftside = leftside + mid(ipk(i)).*(Ak{i}*box - bk{i});
       rightside = rightside + rad(ipk(i)).*abs( (Ak{i}*box - bk{i}) );
                    
    end
    
    leftside = abs(leftside);
 
    if any(leftside > rightside)
       flag = 0;        
    end
    
    newbox = box;
    %unf=0;
 
end
