function [newbox, unf] = prune_horacek(box, ipk, Ak, bk, A, b)
%BEGINDOC=================================================================
% .Author.
%
%   Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Pruning condition by necessary condition for solution of param. system
%   by doc.Mgr.Milan Hladik,PhD.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   box ... column interval vector / matrix of interval column
%   vectors initial boxe(s) 
%   ipk ... column vector of intervals - bounds for parameters
%   Ak ... cellular array of arrays A{1}=[], A{2}=[]
%   bk ... cellular array of column vectors b{1}=, b{2}=
%   A ... real matrix  
%   b ... real column vector 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newbox ... the new box after pruning the box from input
%   unf ... indicator for intersection, unf = 0 if the intersection is
%   empty otherwise unf = 1
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-06-29    first version
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================
  
    [m, n] = size(A);  
    
    unf = 0;

    paramnum = length(ipk); 
    xc = mid(box);
  
    % creating  M(xc) and ip^T
    ip = [infsup(1)];
    M = [A*box - b];
    for i=1:paramnum    
       ip = [ip, ipk(i)];                   
       M = [M, Ak{i}*box - bk{i}];                   
    end
  
    k = paramnum + 1; 
  
    AA = M;
    bb = zeros(m, 1);

    
    [iC, id] = randsubsq(AA, bb);
    ix = iC \ id;      
    for i=1:3
      [iC, id] = randsubsq(AA, bb);
    newix = iC \ id;  
    ix = intersect(newix, ix);
    end
    ix  
  
    if (any(isempty(intersect(ix', ip)))) 
      unf = 1;
    end
 
    newbox = box;
end

