function [initx, pk, Ak, bk, A, b] = tests(name)
%BEGINDOC=================================================================
% .Author.
%
%  Adam Szabo
%
%-------------------------------------------------------------------------
% .Description.
%
%   This function helps to load easier the parametric interval linear 
%   systems examples.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   name ... name of the parametric interval linear system example
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   initx ... column interval vector / matrix of interval column vectors
%   initial boxe(s) 
%   pk ... column vector of intervals - bounds for parameters
%   Ak ... cellular array of arrays A{1}=[], A{2}=[]
%   bk ... cellular array of column vectors b{1}=, b{2}=
%   A ... real matrix  
%   b ... real column vector 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   In comments of each example we can found the source, the name of 
%   the source and the bonus, such as picture, solution...
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2017  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2017-04-23    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%   Other examples. 
%
%ENDDOC===================================================================


pkg load interval

switch (name)
    
%-------------------------------------------------------------------------------   
  %  
  % Popova, E. D., & KrĂ¤mer, W. Visualizing parametric solution sets. 
  % BIT Numerical Mathematics, 48(1):95-115, 2008. 
  % example 3.1  
  % picture
  case 'Popova1'    
    initx = infsup([-1; 0], [1;1]);
   %initx = infsup([0; 0.5], [0.1;0.51]);
    pk = [infsup(0,1)];    
    Ak = {[3 0; 0 3]};    
    bk = {[2;1]};    
    A = [0 1; -2 -1];
    b = [0;0];    
    
%-------------------------------------------------------------------------------    
  %  
  % Popova, E. D., & KrĂ¤mer, W. Visualizing parametric solution sets. 
  % BIT Numerical Mathematics, 48(1):95-115, 2008. 
  % example 3.4  
  % picture
  case 'Popova2'    
    initx = [infsup(-0.5, 1); infsup(-1,-0.5)];
    pk = [infsup(-2,-1);infsup(3,5)];

    Ak{1} = [1 0; 0 1];
    Ak{2} = [0 1; 1 0];
    
    bk{1} = [0;0];
    bk{2} = [-1;1];
    
    A = [0 -1; 0 0];
    b = [1/3;0];
    
%-------------------------------------------------------------------------------      
  %  
  % Popova, E. D., & KrĂ¤mer, W. Visualizing parametric solution sets. 
  % BIT Numerical Mathematics, 48(1):95-115, 2008. 
  % example 4.2  
  % picture + solutionfunction [initx, pk, Ak, bk, A, b] = testParams(X)
  case 'Popova3'    
    initx = [infsup(-2, 2.5); infsup(-2.5,2)];
    pk = [infsup(0,1);infsup(-4,-1);infsup(0,2)];

    Ak{1} = [0 1; 1 0];
    Ak{2} = [0 0; 0 1];
    Ak{3} = [0 0; 0 0];
    
    bk{1} = [0;0];
    bk{2} = [0;0];
    bk{3} = [1;1];
    
    A = [1 0; 0 0];
    b = [0;0];
    
%-------------------------------------------------------------------------------     
  %  
  % Popova, E. D., & KrĂ¤mer, W. Visualizing parametric solution sets. 
  % BIT Numerical Mathematics, 48(1):95-115, 2008. 
  % example 4.3   
  % picture + solution
  case 'Popova4'    
    initx = [infsup(-2,2); infsup(-2,2)];
    pk = [infsup(1,2);infsup(-1.2,2);infsup(-2,2)];

    Ak{1} = [2 0; 0 2];
    Ak{2} = [0 -1; 1 0];
    Ak{3} = [0 0; 0 0];
    
    bk{1} = [0;0];
    bk{2} = [0;0];
    bk{3} = [1;1];
    
    A = [0 0; 0 0];
    b = [0;0]; 
    
    
%-------------------------------------------------------------------------------         
   % Kulpa, Analysis of linear mechanical structures with uncertainties by
   % means of interval methods, 1998 
   
   case 'Kulpa1'
    initx = [infsup(-2,2); infsup(0,4)];
    pk = [infsup(0, 1)];

    Ak{1} = [1 0; 0 3];
    
    bk{1} = [2;0];
    
    A = [0 1; -2 -1];
    b = [0;0];   
    
%-------------------------------------------------------------------------------   
  %  
  % Popova, E. D., & KrĂ¤mer, W. Visualizing parametric solution sets. 
  % BIT Numerical Mathematics, 48(1):95-115, 2008. 
  % example 5.1   
  % picture 
  case 'Popova5'    
    initx = [infsup(-2, 6); infsup(-3,1);infsup(0,0)];
    pk = [infsup(-1/2,1);infsup(-1/2,1/2);infsup(0,1)];

    Ak{1} = [0 1 0; 1 0 1; 0 1 0];
    Ak{2} = [0 0 1; 0 0 0; 1 0 0];
    Ak{3} = [0 0 0; 0 0 0; 0 0 0];
    
    bk{1} = [0;0;0];
    bk{2} = [0;0;0];
    bk{3} = [-1;1/3;1/2];
    
    A = [1 0 0; 0 2 0; 0 0 3];
    b = [1;1;0]; 
    
%-------------------------------------------------------------------------------   
  %  
  % Popova, E. D., & KrĂ¤mer, W. Visualizing parametric solution sets. 
  % BIT Numerical Mathematics, 48(1):95-115, 2008. 
  % example 5.3  
  % picture   
  case 'Popova6'    
    initx = [infsup(7,7.2); infsup(4.1,4.3);infsup(0,0);infsup(0,0);infsup(0,0)];
    pk = [infsup(0.99,1.01);infsup(0.99,1.01);infsup(0.99,1.01);infsup(0.99,1.01);infsup(0.99,1.01);infsup(0.99,1.01);infsup(0.99,1.01);infsup(0.99,1.01);infsup(0.99,1.01)];

    Ak{1} = [1 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0];
    Ak{2} = [0 0 0 0 0; 0 1 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0];
    Ak{3} = [0 0 0 0 0; 0 0 0 0 0; 0 0 1 0 0; 0 0 0 0 0; 0 0 0 0 0];
    Ak{4} = [0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 1 0; 0 0 0 0 0];
    Ak{5} = [0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 1];
    Ak{6} = [1 -1 0 0 0; -1 1 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0];
    Ak{7} = [0 0 0 0 0; 0 1 -1 0 0; 0 -1 1 0 0; 0 0 0 0 0; 0 0 0 0 0];
    Ak{8} = [0 0 0 0 0; 0 0 0 0 0; 0 0 1 -1 0; 0 0 -1 1 0; 0 0 0 0 0];
    Ak{9} = [0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 1 -1; 0 0 0 -1 1];

    
    bk{1} = [0;0;0;0;0];
    bk{2} = [0;0;0;0;0];
    bk{3} = [0;0;0;0;0];
    bk{4} = [0;0;0;0;0];
    bk{5} = [0;0;0;0;0];
    bk{6} = [0;0;0;0;0];
    bk{7} = [0;0;0;0;0];
    bk{8} = [0;0;0;0;0];
    bk{9} = [0;0;0;0;0];
    
    A = [0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0; 0 0 0 0 0;];
    b = [10; 0; 10; 0; 0];
    
%-------------------------------------------------------------------------------   
  %  
  % Evgenija Popova, Walter Kramer. Inner and outer bounds for the solution set 
  % of parametric linear systems, 2007.
  % chapter 4 -ParLinSys software   
  % unsolvable
  case 'Popova7'    
    initx = [infsup(-1, 1); infsup(-1,1)];
    pk = [infsup(2.9,3.1)];
    Ak = {[0 1; 1 3.1]};
    bk = {[0;0]};
    A = [1 0; 0 0.09];
    b = [1;1]; 

%-------------------------------------------------------------------------------     
  %  
  % Evgenija D. Popova. Explicit Description of AE Solution Sets for Parametric 
  % Linear Systems, 2012.
  % example 5.1   
  % picture + solution
  case 'Popova8'    
    initx = [infsup(-2,6); infsup(-3.5,4)];
    pk = [infsup(1/2,3/2);infsup(7/10,17/10);infsup(0,1);infsup(13/6,17/6)];

    Ak{1} = [2 -1; 0 0];
    Ak{2} = [0 0; 1 1];
    Ak{3} = [0 1; 2.5 0];
    Ak{4} = [0 0; 0 0];
    
    bk{1} = [0;0];
    bk{2} = [0;0];
    bk{3} = [0;0];
    bk{4} = [2;2];
    
    A = [0 0; 0 0];
    b = [0;0]; 
    
%-------------------------------------------------------------------------------     
  %  
  % Evgenija D. Popova. Explicit Description of AE Solution Sets for Parametric 
  % Linear Systems, 2012.
  % example 5.3   
  % picture + solution
  case 'Popova9'    
    initx = [infsup(-4.5,2.5); infsup(-2.5,4.5)];
    pk = [infsup(-2,2);infsup(-1,2);infsup(1,2)];

    Ak{1} = [1 0; 0 1];
    Ak{2} = [0 -1; 1 0];
    Ak{3} = [0 0; 0 0];
  
    bk{1} = [0;0];
    bk{2} = [0;0];
    bk{3} = [2;2];
        
    A = [0 0; 0 0];
    b = [0;0];     
 
%-------------------------------------------------------------------------------     
  %  
  % Evgenija D. Popova. Explicit Description of AE Solution Sets for Parametric 
  % Linear Systems, 2012.
  % example 5.4   
  % picture + solution
  case 'Popova10'    
    initx = [infsup(0,1); infsup(-0.4,0.4)];
    pk = [infsup(1,2);infsup(-1,1);infsup(-1/10,1/10)];

    Ak{1} = [2 0; 0 2];
    Ak{2} = [0 1; 1 0];
    Ak{3} = [0 0; 0 0];
  
    bk{1} = [0;0];
    bk{2} = [0;0];
    bk{3} = [1;1];
        
    A = [0 0; 0 0];
    b = [3/2;0]; 
    
%-------------------------------------------------------------------------------     
  %  
  % Evgenija D. Popova. Solvability of parametric interval linear systems of 
  % equations and inequalities, 2015.
  % example 3.2   
  % 
  case 'Popova11'    
    initx = [infsup(-2,0.5); infsup(0.5,3)];
    pk = [infsup(1,2)];
    Ak = {[0 0; 0 0]};
    bk = {[1;2]};        
    A = [1 1; -2 1];
    b = [0;0]; 
    
%-------------------------------------------------------------------------------     
  %  
  % Evgenija D. Popova, Milan Hladik. Outer enclosures to the parametric AE 
  % solution set, 2013.
  % Example 1  from Popova and Kramer (2011)
  % solution + picture
  case 'Popova12'    
    initx = [infsup(-4,4); infsup(-3,3)];
    pk = [infsup(0,1);infsup(0,1);infsup(-1,1);infsup(-1,1)];

    Ak{1} = [1 1; 0 0];
    Ak{2} = [0 0; 1 0];
    Ak{3} = [0 0; 0 0];
    Ak{4} = [0 0; 0 -2];
  
    bk{1} = [0;0];
    bk{2} = [0;-3];
    bk{3} = [1;0];
    bk{4} = [0;0];
        
    A = [0 1; 1 0];
    b = [0;1]; 
    
%-------------------------------------------------------------------------------     
  %  
  % Evgenija D. Popova, Milan Hladik. Outer enclosures to the parametric AE 
  % solution set, 2013.
  % Example 2
  % solution
  case 'Popova13'    
    initx = [infsup(-5,5); infsup(-5,5)];
    pk = [infsup(0,1);infsup(1/3,1);infsup(-1,2);infsup(-1,2)];

    Ak{1} = [1 0; 0 1];
    Ak{2} = [0 1; -2 0];
    Ak{3} = [0 0; 0 0];
    Ak{4} = [0 0; 0 0];
  
    bk{1} = [0;0];
    bk{2} = [0;0];
    bk{3} = [1;1];
    bk{4} = [0;-1];
        
    A = [0 1/2; 0 1];
    b = [0;0]; 
    
%-------------------------------------------------------------------------------     
  %  
  % Evgenija D. Popova, Milan Hladik. Outer enclosures to the parametric AE 
  % solution set, 2013.
  % Example 3
  % solution + picture
  case 'Popova14'    
    initx = [infsup(1,5); infsup(-3.5,0)];
    pk = [infsup(0,1/2);infsup(1,3/2);infsup(1,3/2)];

    Ak{1} = [1 0; 0 1];
    Ak{2} = [0 -1; 1 0];
    Ak{3} = [0 0; 0 0];
  
    bk{1} = [0;0];
    bk{2} = [0;0];
    bk{3} = [2;2];
        
    A = [0 0; 0 0];
    b = [0;0]; 
    
%-------------------------------------------------------------------------------     
  %  
  % Evgenija D. Popova, Milan Hladik. Outer enclosures to the parametric AE 
  % solution set, 2013.
  % Example 4
  % solution + picture
  case 'Popova15'    
    initx = [infsup(0,10); infsup(-5,10)];
    pk = [infsup(1/2,3/2);infsup(0,1);infsup(1,2)];

    Ak{1} = [1 0; 0 1];
    Ak{2} = [0 -1; 1 0];
    Ak{3} = [0 0; 0 0];
  
    bk{1} = [0;0];
    bk{2} = [0;0];
    bk{3} = [2;2];
        
    A = [0 0; 0 0];
    b = [0;0];    
    
%-------------------------------------------------------------------------------   
  %  
  % Popova, E. D., & KrĂ¤mer, W. Visualizing parametric solution sets. 
  % BIT Numerical Mathematics, 48(1):95-115, 2008. 
  % example 3.2 - 3D linear system  
  % picture
  case 'Popova3D1'
    initx = [infsup(-0.1, 1.15); infsup(-0.1,0.1); infsup(-0.15,0.05)];
    pk = [infsup(0,1);infsup(0,0.9)];
    
    Ak{1} = [0 1 0; 1 0 1; 0 1 0];
    Ak{2} = [0 0 1; 0 0 0; 1 0 0];
    
    bk{1} = [0;1^2;0];
    bk{2} = [0;0;1^2];
    
    A = [1 0 0; 0 2 0; 0 0 3];
    b = [1;0;0]; 
    
%-------------------------------------------------------------------------------   
  %  
  % Popova, E. D., & KrĂ¤mer, W. Visualizing parametric solution sets. 
  % BIT Numerical Mathematics, 48(1):95-115, 2008. 
  % example 3.3 - 3D linear system  
  % picture
  case 'Popova3D2'
    initx = [infsup(-0.1, 1.15); infsup(-0.1,0.1); infsup(-0.15,0.05)];
    pk = [infsup(-0.2,0.1)];
    Ak = {[0 1 1; 1 0 1; 1 1 0]};
    bk = {[0;1^2;1^2]};
    A = [1 0 0; 0 2 0; 0 0 3];
    b = [1;0;0]; 
    
%------------------------------------------------------------------------------- 
  %
  % Moore, Ramon E., R. Baker Kearfott, and Michael J. Cloud. 
  % Introduction to interval analysis. Siam, 2009. 
  % 7.6
  % picture 
  case 'Moore1'    
    initx = [infsup(-5, 5); infsup(-5,5)];
    pk = {};
    Ak = {};       
    bk = {};    
    A = [infsup(2, 4) infsup(-2, 1); infsup(-1, 2) infsup(2, 4)];
    b = [infsup(-2, 2); infsup(-2, 2)];  
    
%------------------------------------------------------------------------------- 
  %  
  % Z Kulpa, A Pownuk, I Skalna. Computer Assisted Mechanics and Engineering 
  % Sciences 5 (4), 443-477, 1998.
  % A parametric system example of page 27. 
  % picture + solution
  case 'Skalna1'    
    initx = [infsup(-2.5, 3); infsup(-1,5)];
    pk = [infsup(0,1)];
    Ak = {[1 0; 0 3]};   
    bk = {[2;0]};
    A = [0 1; -2 -1];
    b = [0;0];
    
%-------------------------------------------------------------------------------     
  %  
  % Z Kulpa, A Pownuk, I Skalna. Computer Assisted Mechanics and Engineering 
  % Sciences 5 (4), 443-477, 1998.
  % A Rump-Behnke example of page 28. 
  % picture
  case 'Skalna2'    
    initx = [infsup(0, 4); infsup(0,4)];
    pk = [infsup(1,2)];
    Ak = {[0 1; 1 0]};
    bk = {[0;0]};
    
    A = [3 0; 0 3];
    b = [infsup(10, 10.5); infsup(10, 10.5)]; 
    
%-------------------------------------------------------------------------------   
  %  
  % Z Kulpa, A Pownuk, I Skalna. Computer Assisted Mechanics and Engineering 
  % Sciences 5 (4), 443-477, 1998.
  % A solution set of an example singular system of page 32. 
  % picture
  case 'Skalna3'    
    initx = [infsup(-6, 6); infsup(-8,6)];
    pk = [infsup(0,1)];

    Ak = {[2 0; 0 2]};
    
    bk = {[2;0]};

    
    A = [0 1; -1 -1];
    b = [0;2];    
    
%------------------------------------------------------------------------------- 
  %  
  % I Skalna. International Conference on Numerical Methods and Applications, 
  % 361-368, 2006.
  % example 1
  % numerical result
  case 'Skalna4'    
    initx = [infsup(-2.5, 2); infsup(-1,4.5)];
    pk = [infsup(0,1);infsup(0,1)];

    Ak{1} = [1 0; 0 3];
    Ak{2} = [0 1; 0 0]
    
    bk{1} = [2;0];
    bk{2} = [0;0]

    
    A = [0 1; -2 -1];
    b = [0;0]; 
    
%-------------------------------------------------------------------------------    
  %  
  % I Skalna. International Conference on Numerical Methods and Applications, 
  % 361-368, 2006. 
  % example 2   
  % numerical result 
  % with axis 'z' is very slowly! -> z = 0,0
  case 'Skalna5'    
    initx = [infsup(-2, 1); infsup(-0.5,0.5);infsup(0,0)];
    pk = [infsup(0,1);infsup(0,1);infsup(0,1)];

    Ak{1} = [1 0 0; 0 0 1; 0 0 0];
    Ak{2} = [0 1 0; 1 0 0; 0 4 0];
    Ak{3} = [0 0 -1; 0 0 0; -1 0 0];
    
    bk{1} = [2;0;0];
    bk{2} = [0;0;0];
    bk{3} = [0;1;0];
    
    A = [0 1 0; 1 -3 0; 2 1 1];
    b = [0;-1;-1];   
   
%-------------------------------------------------------------------------------    
  %  
  % El-Owny, Hassan Badry Mohamed; ,Solving parametric linear systems 
  % iteratively, 351-356, 2013.
  % Example(1)  
  % numerical result 
  % 
  case 'El-Owny1'    
    initx = [infsup(4, 7); infsup(2,4.5)];
    pk = [infsup(-0.6,-0.4);infsup(1.8,2.2)];

    Ak{1} = [0 1; 1 0];
    Ak{2} = [0 0; 0 1];
 
    bk{1} = [0;0];
    bk{2} = [1;1];
    
    A = [1 0; 0 0];
    b = [2;2]; 
    
%-------------------------------------------------------------------------------    
  %  
  % El-Owny, Hassan Badry Mohamed; ,Solving parametric linear systems 
  % iteratively, 351-356, 2013.
  % Example(2)  
  % numerical result 
  % 
  case 'El-Owny2'    
    initx = [infsup(0, 1); infsup(0,0.5); infsup(-0.5,0.5)];
    pk = [infsup(0,1)];
    Ak = {[0 1 1; 1 0 1; 1 1 0]};
    bk = {[0;0;0]};  
    A = [3 0 0; 0 3 0; 0 0 3]; 
    b = [1;1;1];
 
%-------------------------------------------------------------------------------    
  %  
  % El-Owny, Hassan Badry Mohamed; ,Solving parametric linear systems 
  % iteratively, 351-356, 2013.
  % Example(3)  
  % numerical result 
  % 
  case 'El-Owny3'    
    initx = [infsup(-1, -0.2); infsup(3,6); infsup(1,2)];
    pk = [infsup(0.4,0.5);infsup(0.2,0.3)];

    Ak{1} = [1 1 0; 0 1 0; 0 0 3];
    Ak{2} = [1 0 1; 0 1 1; 0 0 1];
 
    bk{1} = [1;1;2];
    bk{2} = [5;3;1];
    
    A = [1 0 0; 0 0 0; 0.1 0 0]; 
    b = [0;2;1]; 
    
%-------------------------------------------------------------------------------       

  case 'Test'    
    initx = infsup([-1; 0], [1;1]);
    pk = [infsup(0,1)];    
    Ak = {[0 3; 3 0]};    
    bk = {[2;1]};    
    A = [0 1; -2 0];
    b = [0;0];  
    
%-------------------------------------------------------------------------------   
    
  otherwise
    disp('Error: input does not exist') 
  
endswitch

end